@@ -26,7 +26,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.2.2"
+version = "1.2.3"
 
 major = str(sys.version_info.major)
 minor = str(sys.version_info.minor)
@@ -258,17 +258,6 @@ class ip:
                     if code == 200:
                         print(f"{space}{B} DONE {w} Status: {g}valid{w} URL: {url}")
             sub = False
-    def smtp(email:str, *message:str):
-        import socket, requests
-        server = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-        mail_ip = str(server["mailip"])
-        mail_port = int(server["mailport"])
-        message = " ".join([str(m) for m in message])
-        client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        client.connect((mail_ip, mail_port))
-        client.sendall(bytes("smtp|de|"+email+"|"+message,'UTF-8'))
-        code = client.recv(4096)
-        print(code)
     def telegram(data=False):
         import requests
         infinity = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
